@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/macperl/perl/macos/ext/Mac/Carbon/Carbon.h,v 1.10 2003/08/13 21:41:30 pudge Exp $
+/* $Header: /cvsroot/macperl/perl/macos/ext/Mac/Carbon/Carbon.h,v 1.11 2003/10/28 05:49:29 pudge Exp $
  *
  *    Copyright (c) 2002 Matthias Neeracher, Chris Nandor
  *
@@ -6,6 +6,9 @@
  *    as specified in the README file.
  *
  * $Log: Carbon.h,v $
+ * Revision 1.11  2003/10/28 05:49:29  pudge
+ * Add #undef I_POLL for Panther
+ *
  * Revision 1.10  2003/08/13 21:41:30  pudge
  * undef DEBUG for the sake of gcc 3.3 (perl's DEBUG conflicts with Mac's)
  *
@@ -47,6 +50,7 @@
 
 /* Perl defines Move too */
 #undef Move
+#undef I_POLL
 #undef DEBUG
 #include <Events.h>
 #include <Dialogs.h>
